<?php

/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://example.com
 * @since      1.0.0
 *
 * @package    Sharekayak_Kayak_Booking
 * @subpackage Sharekayak_Kayak_Booking/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Sharekayak_Kayak_Booking
 * @subpackage Sharekayak_Kayak_Booking/admin
 * @author     Sharekayak <example@gmail.com>
 */
class Sharekayak_Kayak_Booking_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @access   private
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string    $plugin_name       The name of this plugin.
	 * @param      string    $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {

		$this->plugin_name = $plugin_name;
		$this->version = $version;

	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Sharekayak_Kayak_Booking_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Sharekayak_Kayak_Booking_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/sharekayak-kayak-booking-admin.css', array(), $this->version, 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Sharekayak_Kayak_Booking_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Sharekayak_Kayak_Booking_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */

		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/sharekayak-kayak-booking-admin.js', array( 'jquery' ), $this->version, false );

	}
	
	public function add_menu() {
        add_menu_page('Sharekayak Booking Settings', 'Sharekayak Booking', 'manage_options', 'sharekayak_booking', array($this, 'settings_page'));
    }

    public function settings_page() {
        if (isset($_POST['iframe_url'])) {
            update_option('iframe_url', $_POST['iframe_url']);
        }

        $url = get_option('iframe_url');
        ?>
        <div class="wrap">
            <h2>Sharekayak booking</h2>
            <form method="post">
                <label for="iframe_url" class="label">Enter Your Operator URL:</label><br>
                <input type="text" id="iframe_url" name="iframe_url" value="<?php echo $url; ?>"><br><br>
                <input type="submit" value="Save URL">
            </form>
        </div>
        <?php
    }

    public function add_iframe_button() {
        $url = get_option('iframe_url');

        // Check if URL is empty
        if (!empty($url)) {
            echo '<div style="text-align: center;"><button id="openModal" style="position: fixed; bottom: 50px; right: 50px; padding: 10px 20px; background-color: rgb(76, 175, 80); color: white; border: none; border-radius: 5px; cursor: pointer; font-size: 16px; z-index: 9999;">Advance Booking</button></div>';
            echo '<div class="overlay" id="overlay" style="display: none; position: fixed; top: 0; left: 0; width: 100%; height: 100%; background: rgba(0, 0, 0, 0.7); z-index: 9998;"></div>';
            echo '<div class="custom-modal" id="customModal" style="display: none; position: fixed; top: 50%; left: 50%; transform: translate(-50%, -50%); background: #fff;  padding: 20px; max-width: 100%; max-height: 80%; width: 90%; height: 100%; z-index: 9999;">
            <div class="modal-content" style="position: relative; border:none; padding:0;height: 100%; width: 100%;">
                <iframe id="iframeContainer" style="width: 100%; height: calc(100% - 40px); border: none;"></iframe>
                <button class="close-bottom" id="closeBottom" style="position: absolute; bottom: -10px; right:0px; padding: 5px 10px; background-color: rgb(76, 175, 80); color: white; border: none; border-radius: 5px; cursor: pointer;">Close</button>
            </div>
        </div>';
        }

        echo "<script>
                document.getElementById('openModal').addEventListener('click', function() {
                    var customModal = document.getElementById('customModal');
                    var overlay = document.getElementById('overlay');
                    var iframe = document.getElementById('iframeContainer');
                    overlay.style.display = 'block';
                    iframe.src = '" . $url . "';
                    customModal.style.display = 'block';
                });

                document.getElementById('closeBottom').addEventListener('click', function() {
                    var customModal = document.getElementById('customModal');
                    var overlay = document.getElementById('overlay');
                    overlay.style.display = 'none';
                    customModal.style.display = 'none';
                });
              </script>";
    }

}
